/* Convert HTML tags to uppercase */

/* Leave debug information on errors */
signal on error   name Quit
signal on failure name Quit
signal on halt    name Quit
signal on syntax  name Quit

/* Initialize RexxUtil */
if RxFuncQuery( "SysLoadFuncs" ) <> 0 then do
	call RxFuncAdd "SysLoadFuncs", "RexxUtil", "SysLoadFuncs"
	call SysLoadFuncs
end

/* Parse command line parameter(s) */
parse upper arg infiles dummy
if dummy  <> "" then call Syntax
if infiles = "" then call Syntax

/* Check if file(s) exist */
call SysFileTree infiles, "infile.", "F"
if infile.0 = 0 then call Syntax "FileNotFound", infiles

/* Covert tags in all specified files to uppercase */
do i = 1 to infile.0
	call CheckTags infile.i
end
EXIT


CheckTags: procedure expose outfile
	/* Parse argument(s) */
	infile = arg( 1 )
	parse value infile with . . size . file
	file = strip( file )
	parse upper value file with outfile".HTM"
	outfile = outfile||".UPC"

	/* Read file */
	allstring = charin( file, 1, size )
	call lineout file

	/* Find all tags and convert them */
	newstring = ""
	convert   = 1
	do forever
		parse value allstring with string"<"tag">"allstring
		if tag = "" then do
			leave
		end
		newtag = ConvertTag( tag )
		if newtag = "/SCRIPT" then convert = 1
		if convert = 1 then tag = newtag
		say "Converted tag: <"||tag||">"||"0D0A"X
		newstring = newstring||string||"<"||tag||">"
		if left( newtag, 6 ) = "SCRIPT" then convert = 0
	end
	if allstring <> "" then newstring = newstring||allstring

	/* Save results */
	call charout outfile, newstring
	call lineout outfile
return


ColorConvert: procedure expose outfile
	/* Parse argument(s) */
	args = arg( )
	string = arg( 1 )
	if string > 1 then do i = 2 to args
		string = string||","||arg( i )
	end

	/* Check if string is hex color designation */
	/* and convert to uppercase if true         */
	if length( string ) = 7 then do
		if left( string, 1 ) = "#" then do
			if datatype( right( string, 6 ), "X" ) = 1 then do
				string = translate( string )
			end
		end
	end
return string


ConvertTag: procedure expose outfile
	/* Parse argument(s) */
	args = arg( )
	tag = arg( 1 )
	if args > 1 then do i = 2 to args
		tag = tag||","||arg( i )
	end
	say "Original tag:  <"||tag||">"

	/* First, remove line breaks from within tag */
	do until break = 0
		break = pos( "0D0A"X, tag )
		if break > 1 then do
			tag = substr( tag, 1, break - 1 )||" "||,
			      substr( tag, break + 2 )
		end
	end

	/* Then, check for literals within tag */
	if pos( '"', tag ) = 0 then do
		newtag = translate( tag )
	end
	else do
		newtag   = ""
		do until qposo = 0
			qposo = pos( '"', tag )
			if qposo > 1 then do
				newtag = newtag||translate( substr( tag, 1, qposo ) )
				tag = substr( tag, qposo + 1 )
			end
			qposc = pos( '"', tag )
			if qposc > 1 then do
				qstr = substr( tag, 1, qposc - 1 )
				newtag = newtag||ColorConvert( qstr )||'"'
				tag = substr( tag, qposc + 1 )
			end
			else do
				if qposc = 1 then do
					newtag = newtag||'"'
					tag = substr( tag, 2 )
				end
				else leave
			end
		end
		if tag <> "" then newtag = newtag||tag
	end
return newtag


Quit: procedure expose outfile
	call lineout outfile
	exit
return


Syntax: procedure expose outfile
	say
	errortype = arg( 1 )
	if errortype = "FileNotFound" then do
		infiles = arg( 2 )
		say "Error"
		say "file(s) not found: "||infiles
	end
	else do
		say "Convert HTML tag commands to uppercase"
	end
	say
	say "Usage: HTMLTAGS  <html_filespec>"
	call Quit
return
